#ifndef R_JSONIFY_H
#define R_JSONIFY_H

#include <Rcpp.h>

// [[Rcpp::depends(rapidjsonr)]]

#include "rapidjson/writer.h"
#include "rapidjson/stringbuffer.h"
#include "rapidjson/prettywriter.h"
#include "jsonify/to_json/api.hpp"

#endif
